@@ -1,6 +1,8 @@
 package Template::Reverse::Spacer::Numeric;
 use Any::Moose;
-our $VERSION = '0.002';
+use namespace::autoclean;
+
+our $VERSION = '0.003';
 sub Space{
     my $self = shift;
     my $str = shift;
@@ -24,7 +26,7 @@ Template::Reverse::Spacer::Numeric - Insert spaces around Numeric word.
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
     
@@ -34,6 +36,5 @@ version 0.002
 
 =cut
 
-
-
+__PACKAGE__->meta->make_immutable;
 1;
